@@ -28,19 +28,21 @@ class TestRewindCache(unittest.TestCase):
         dpkg_status = os.path.abspath(
             os.path.join(rootdir, "var", "lib", "dpkg", "status"))
         apt.apt_pkg.config.set("Dir::State::status", dpkg_status)
-        self.allowed_origins = ["origin=Ubuntu,archive=lucid-security"]
+        apt.apt_pkg.config.set(
+            "Unattended-Upgrade::Allow-APT-Mark-Fallback", "true")
         self.cache = unattended_upgrade.UnattendedUpgradesCache(
-            rootdir=rootdir, allowed_origins=self.allowed_origins)
+            rootdir=rootdir)
 
     def test_rewind_cache(self):
         """ Test that rewinding the cache works correctly, debian #743594 """
         options = MockOptions()
-        blacklist = []
-        whitelist = []
-        to_upgrade, kept_back = unattended_upgrade.calculate_upgradable_pkgs(
-            self.cache, options, self.allowed_origins, blacklist, whitelist)
-        self.assertEqual(to_upgrade, [self.cache["test-package"]])
-        self.assertEqual(kept_back, ["z-package"])
+        to_upgrade = unattended_upgrade.calculate_upgradable_pkgs(
+            self.cache, options)
+        self.assertEqual(to_upgrade, [self.cache[p] for p
+                                      in ["test-package", "test2-package",
+                                          "test3-package"]])
+        unattended_upgrade.rewind_cache(self.cache, to_upgrade)
+        self.assertEqual(self.cache['test-package'].candidate.version, "2.0")
 
 
 if __name__ == "__main__":
